# SAP BTP, Cloud Foundry Integration for SAP Discovery
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration#prerequisites)
  * [Step 1: Create a Platform User in Your IAS Tenant](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration#step-1:-create-a-platform-user-in-your-ias-tenant)
  * [Step 2: Create an SAP Cloud Management Service Instance and Service Key](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration#step-2:-create-an-sap-cloud-management-service-instance-and-service-key)
  * [Step 3: Add the Platform User to SAP BTP, Cloud Foundry Organizations and Spaces](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration#step-3:-add-the-platform-user-to-sap-btp,-cloud-foundry-organizations-and-spaces)
  * [Step 4: Connect SAP LeanIX to SAP BTP, Cloud Foundry](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration#step-4:-connect-sap-leanix-to-sap-btp,-cloud-foundry)
  * [Linking Discovered Items to Fact Sheets](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration#linking-discovered-items-to-fact-sheets)
  * [Viewing Synchronization Logs](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration#viewing-synchronization-logs)
  * [SAP BTP Meta Model Extension](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration#sap-btp-meta-model-extension)


Connect your SAP BTP, Cloud Foundry environment to SAP LeanIX to improve the visibility of self-built applications within your enterprise architecture.
